@@ -23,21 +23,21 @@ test_that("ggpredict, brms-ppd", {
     iter = 500,
     refresh = 0
   ))
-  expect_s3_class(suppressWarnings(ggpredict(m1, interval = "prediction")), c("ggalleffects", "list"))
-  expect_s3_class(suppressWarnings(ggpredict(m1, "x", interval = "prediction")), "data.frame")
-  expect_s3_class(ggpredict(m1, interval = "prediction"), c("ggalleffects", "list"))
-  expect_s3_class(ggpredict(m1, "x", interval = "prediction"), "data.frame")
+  expect_s3_class(suppressWarnings(ggpredict(m1, interval = "prediction", verbose = FALSE)), c("ggalleffects", "list"))
+  expect_s3_class(suppressWarnings(ggpredict(m1, "x", interval = "prediction", verbose = FALSE)), "data.frame")
+  expect_s3_class(ggpredict(m1, interval = "prediction", verbose = FALSE), c("ggalleffects", "list"))
+  expect_s3_class(ggpredict(m1, "x", interval = "prediction", verbose = FALSE), "data.frame")
   expect_s3_class(suppressWarnings(ggpredict(m2, interval = "prediction")), c("ggalleffects", "list"))
   expect_s3_class(suppressWarnings(ggpredict(m2, "x", interval = "prediction")), "data.frame")
-  expect_s3_class(ggpredict(m1, interval = "confidence"), c("ggalleffects", "list"))
-  expect_s3_class(ggpredict(m1, "x", interval = "confidence"), "data.frame")
+  expect_s3_class(ggpredict(m1, interval = "confidence", verbose = FALSE), c("ggalleffects", "list"))
+  expect_s3_class(ggpredict(m1, "x", interval = "confidence", verbose = FALSE), "data.frame")
   expect_s3_class(ggpredict(m2, interval = "confidence"), c("ggalleffects", "list"))
   expect_s3_class(ggpredict(m2, "x", interval = "confidence"), "data.frame")
 
   set.seed(123)
-  out1 <- suppressWarnings(ggpredict(m1, "x", interval = "prediction"))
+  out1 <- suppressWarnings(ggpredict(m1, "x", interval = "prediction", verbose = FALSE))
   set.seed(123)
-  out2 <- ggpredict(m1, "x", interval = "prediction")
+  out2 <- ggpredict(m1, "x", interval = "prediction", verbose = FALSE)
   expect_equal(out1$predicted, out2$predicted, tolerance = 1e-3)
   expect_equal(out1$conf.low, out2$conf.low, tolerance = 1e-3)
 })
