@@ -11,6 +11,6 @@ test_that("ggeffects, pool comparisons", {
     hypothesis_test(m, "age")
   })
   pool_com <- pool_comparisons(comparisons)
-  expect_equal(pool_com$Contrast, c(4.6464, 6.70639, 2.05999), tolerance = 1e-3)
-  expect_equal(pool_com$conf.low, c(-0.3772104, -1.3017958, -4.4172299), tolerance = 1e-3)
+  expect_equal(pool_com$Difference, c(-4.6464, -6.70639, -2.05999), tolerance = 1e-3)
+  expect_equal(pool_com$CI_high, c(0.3772104, 1.3017958, 4.4172299), tolerance = 1e-3)
 })
